Stan Math Library: stan/math/prim/mat/fun/get_base1_lhs.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
get_base1_lhs.hpp File Reference
`#include <stan/math/prim/mat/fun/Eigen.hpp>`
`#include <stan/math/prim/mat/err/check_range.hpp>`
`#include <vector>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
template<typename T >
T & | stan::math::get_base1_lhs (std::vector< T > &x, size_t i, const char *error_msg, size_t idx)
| Return a reference to the value of the specified vector at the specified base-one index. More...
template<typename T >
T & | stan::math::get_base1_lhs (std::vector< std::vector< T > > &x, size_t i1, size_t i2, const char *error_msg, size_t idx)
| Return a reference to the value of the specified vector at the specified base-one indexes. More...
template<typename T >
T & | stan::math::get_base1_lhs (std::vector< std::vector< std::vector< T > > > &x, size_t i1, size_t i2, size_t i3, const char *error_msg, size_t idx)
| Return a reference to the value of the specified vector at the specified base-one indexes. More...
template<typename T >
T & | stan::math::get_base1_lhs (std::vector< std::vector< std::vector< std::vector< T > > > > &x, size_t i1, size_t i2, size_t i3, size_t i4, const char *error_msg, size_t idx)
| Return a reference to the value of the specified vector at the specified base-one indexes. More...
template<typename T >
T & | stan::math::get_base1_lhs (std::vector< std::vector< std::vector< std::vector< std::vector< T > > > > > &x, size_t i1, size_t i2, size_t i3, size_t i4, size_t i5, const char *error_msg, size_t idx)
| Return a reference to the value of the specified vector at the specified base-one indexes. More...
template<typename T >
T & | stan::math::get_base1_lhs (std::vector< std::vector< std::vector< std::vector< std::vector< std::vector< T > > > > > > &x, size_t i1, size_t i2, size_t i3, size_t i4, size_t i5, size_t i6, const char *error_msg, size_t idx)
| Return a reference to the value of the specified vector at the specified base-one indexes. More...
template<typename T >
T & | stan::math::get_base1_lhs (std::vector< std::vector< std::vector< std::vector< std::vector< std::vector< std::vector< T > > > > > > > &x, size_t i1, size_t i2, size_t i3, size_t i4, size_t i5, size_t i6, size_t i7, const char *error_msg, size_t idx)
| Return a reference to the value of the specified vector at the specified base-one indexes. More...
template<typename T >
T & | stan::math::get_base1_lhs (std::vector< std::vector< std::vector< std::vector< std::vector< std::vector< std::vector< std::vector< T > > > > > > > > &x, size_t i1, size_t i2, size_t i3, size_t i4, size_t i5, size_t i6, size_t i7, size_t i8, const char *error_msg, size_t idx)
| Return a reference to the value of the specified vector at the specified base-one indexes. More...
template<typename T >
Eigen::Block< Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > > | stan::math::get_base1_lhs (Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &x, size_t m, const char *error_msg, size_t idx)
| Return a copy of the row of the specified vector at the specified base-one row index. More...
template<typename T >
T & | stan::math::get_base1_lhs (Eigen::Matrix< T, Eigen::Dynamic, Eigen::Dynamic > &x, size_t m, size_t n, const char *error_msg, size_t idx)
| Return a reference to the value of the specified matrix at the specified base-one row and column indexes. More...
template<typename T >
T & | stan::math::get_base1_lhs (Eigen::Matrix< T, Eigen::Dynamic, 1 > &x, size_t m, const char *error_msg, size_t idx)
| Return a reference to the value of the specified column vector at the specified base-one index. More...
template<typename T >
T & | stan::math::get_base1_lhs (Eigen::Matrix< T, 1, Eigen::Dynamic > &x, size_t n, const char *error_msg, size_t idx)
| Return a reference to the value of the specified row vector at the specified base-one index. More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.